mendeleev package
=================

Submodules
----------

.. toctree::

   mendeleev.mendeleev
   mendeleev.plotting
   mendeleev.tables

Module contents
---------------

.. automodule:: mendeleev
    :members:
    :undoc-members:
    :show-inheritance:
